@@ -26,7 +26,7 @@ class CodeInjector:
         # pylint: disable=eval-used
         try:
             result = eval(expression, self.f_globals)
-        except TypeError:
+        except (SyntaxError, ValueError, TypeError):
             # typeerror: e.g. Optional[int]
             result = object()
 
@@ -39,7 +39,6 @@ class CodeInjector:
         :param alternative: express to use if it does not evaluate properly
 
         """
-        # FUTURE - either eliminate evaluate() or get_expression()
         if isinstance(value, int) and not isinstance(value, Enum):
             expression = str(int(value))
             is_same = True
@@ -122,7 +121,7 @@ class CodeInjector:
         try:
             # pylint: disable=eval-used
             is_same = eval(type_hint, self.f_globals, self.namespace) is python_type
-        except NameError:  # pragma: no cover
+        except (NameError, SyntaxError):  # pragma: no cover
             return ""
         except Exception as exc:
             raise RuntimeError(f"invalid type hint: {type_hint!r}") from exc
