@@ -3,16 +3,16 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 """Array to bytes and bytes to array transform."""
 
-from typing import Any, Generator, List, Optional, Sequence, Tuple, Type, Union
+from typing import Any, Generator, List, Optional, Sequence, Tuple, Union
 
-from .data import Data, DataMeta
+from ._typing import Format
+from .data import DataMeta
 from .dump import Record
 from .int import IntX
 from .transform import Transform
 
 Dims = Sequence[Optional[int]]
 DimsArg = Union[Dims, "ArrayX", IntX]
-Format = Union[Type[Data], Transform]
 
 GREEDY_DIMS: Dims = (None,)
 
@@ -31,13 +31,17 @@ class ArrayX(Transform):
     __ndims__: int
     __df__: Tuple[DimsArg, Format]
 
-    def __init__(self, name: str, fmt: Format, dims: Optional[DimsArg] = None) -> None:
-        super().__init__(name)
-
+    def __init__(
+        self,
+        fmt: Format,
+        dims: Optional[DimsArg] = None,
+        name: Optional[str] = None,
+    ) -> None:
         assert isinstance(fmt, (DataMeta, Transform))
 
         locked_dims: DimsArg
-        ndims = 0
+
+        num_dims = 1
 
         if dims is None:
             locked_dims = GREEDY_DIMS
@@ -47,16 +51,24 @@ class ArrayX(Transform):
 
         elif isinstance(dims, ArrayX):
             locked_dims = dims
-            if not dims.__ndims__:
+            dims_dims, _fmt = dims.__df__
+
+            if (
+                not isinstance(dims_dims, tuple)
+                or len(dims_dims) != 1
+                or dims_dims[0] is None
+            ):
                 raise TypeError(
-                    "invalid ArrayX 'dims', must be single dim and non-greedy"
+                    "invalid 'dims', when providing an array transform for `dims`, "
+                    "it must have a single, fixed (non-greedy) dimension"
                 )
 
+            num_dims = dims_dims[0]
+
         else:
             locked_dims = tuple(None if d is None else int(d) for d in dims)
             assert all(True if d is None else d > 0 for d in locked_dims)
-            if (len(locked_dims) == 1) and locked_dims[0] is not None:
-                ndims = locked_dims[0]
+            num_dims = len(dims)
 
         nbytes: Optional[int] = fmt.__nbytes__
 
@@ -72,8 +84,18 @@ class ArrayX(Transform):
             else:
                 nbytes = None
 
+        hint = fmt.__hint__ or "Any"
+
+        for _ in range(num_dims):
+            hint = f"List[{hint}]"
+
+        if name is None:
+            name = hint
+
+        super().__init__(name, hint)
+
         self.__df__ = locked_dims, fmt
-        self.__ndims__ = ndims
+        self.__ndims__ = num_dims
         self.__nbytes__ = nbytes
 
     @property
@@ -112,10 +134,11 @@ class ArrayX(Transform):
                 dims = (dim,)
 
             elif isinstance(x_dims, ArrayX):
+                # must be isinstance(x_dims, ArrayX):
                 dims, offset = x_dims.__unpack__(buffer, offset, dump)
 
             else:  # pragma: no cover
-                raise RuntimeError(f"invalid 'dims' {x_dims!r}")
+                raise RuntimeError("unexpected implementation error")
 
         array: List[Any] = []
         append = array.append
@@ -179,7 +202,7 @@ class ArrayX(Transform):
         if this_dim is None:
             end = len(buffer)
             i = 0
-            fmt_name = fmt.__name__
+            fmt_name = fmt.name
             while offset < end:
                 item, offset = fmt.__unpack__(
                     buffer, offset, dump.add_record(access=f"[{i}]", fmt=fmt_name)
@@ -194,7 +217,7 @@ class ArrayX(Transform):
                 )
                 append(item)
         else:
-            fmt_name = fmt.__name__
+            fmt_name = fmt.name
             for i in range(this_dim):
                 item, offset = fmt.__unpack__(
                     buffer, offset, dump.add_record(access=f"[{i}]", fmt=fmt_name)
@@ -229,7 +252,7 @@ class ArrayX(Transform):
                     x_dims.__pack__(this_dim, pieces, dump)
 
                 elif isinstance(x_dims, ArrayX):
-                    dims = tuple(iterate_dims(value, x_dims.__ndims__))
+                    dims = tuple(iterate_dims(value, self.__ndims__))
                     this_dim, *item_dims = dims
                     x_dims.__pack__(dims, pieces, dump)
 
@@ -275,7 +298,7 @@ class ArrayX(Transform):
                 )
 
             elif isinstance(x_dims, ArrayX):
-                dims = tuple(iterate_dims(value, x_dims.__ndims__))
+                dims = tuple(iterate_dims(value, self.__ndims__))
                 this_dim, *item_dims = dims
                 x_dims.__pack__(
                     dims, pieces, dump.add_record(access="--dims--", fmt=x_dims)
@@ -310,7 +333,7 @@ class ArrayX(Transform):
                     self, item, pieces, dump.add_record(access=f"[{i}]"), item_dims
                 )
         else:
-            fmt_name = fmt.__name__
+            fmt_name = fmt.name
 
             for i, item in zip(range(this_dim), value):
                 fmt.__pack__(
