@@ -15,6 +15,9 @@ class NoneX(Transform):
 
     __nbytes__ = 0
 
+    def __init__(self, name: str = "None") -> None:
+        super().__init__(name, hint="None")
+
     def __pack__(
         self, value: None, pieces: List[bytes], dump: Optional[Record] = None
     ) -> None:
