@@ -7,20 +7,23 @@ import pytest
 
 from plum.array import ArrayX
 from plum.exceptions import SizeError
-from plum.littleendian import uint8
+from plum.littleendian import single, uint8
 from plum.str import StrX
 
-ascii_zero = StrX("ascii_zero", encoding="ascii", zero_termination=True)
+ascii_zero = StrX(name="ascii_zero", encoding="ascii", zero_termination=True)
 
 
 class TestDefault:
 
     """Test with as many left to default as possible."""
 
-    arrayx = ArrayX("arrayx", uint8)
+    arrayx = ArrayX(uint8)
 
     def test_name(self):
-        assert self.arrayx.name == "arrayx"
+        assert self.arrayx.name == "List[int]"
+
+    def test_hint(self):
+        assert self.arrayx.__hint__ == "List[int]"
 
     def test_nbytes(self):
         with pytest.raises(SizeError):
@@ -37,10 +40,13 @@ class TestPositional:
 
     """Test explicitly defined with positional argument."""
 
-    arrayx = ArrayX("arrayx", uint8, (2,))
+    arrayx = ArrayX(uint8, (2,), "name")
 
     def test_name(self):
-        assert self.arrayx.name == "arrayx"
+        assert self.arrayx.name == "name"
+
+    def test_hint(self):
+        assert self.arrayx.__hint__ == "List[int]"
 
     def test_nbytes(self):
         assert self.arrayx.nbytes == 2
@@ -56,7 +62,7 @@ class TestKeyword(TestPositional):
 
     """Test explicitly defined with keyword argument."""
 
-    arrayx = ArrayX(name="arrayx", fmt=uint8, dims=(2,))
+    arrayx = ArrayX(fmt=uint8, dims=(2,), name="name")
 
 
 class TestVariable:
@@ -68,3 +74,30 @@ class TestVariable:
     def test_nbytes(self):
         with pytest.raises(SizeError):
             return self.arrayx.nbytes
+
+
+class TestDefaultNameHint:
+
+    """Test generation of name and type hint."""
+
+    def test_multi_dims(self):
+        arrayx = ArrayX(fmt=uint8, dims=[20, 30, None])
+        assert arrayx.name == arrayx.__hint__ == "List[List[List[int]]]"
+
+    def test_greedy_dim(self):
+        arrayx = ArrayX(fmt=single)
+        assert arrayx.name == arrayx.__hint__ == "List[float]"
+
+    def test_variable_single_dim(self):
+        arrayx = ArrayX(fmt=single, dims=uint8)
+        assert arrayx.name == arrayx.__hint__ == "List[float]"
+
+    def test_variable_multi_dim(self):
+        dimsx = ArrayX(fmt=uint8, dims=[3])
+        arrayx = ArrayX(fmt=single, dims=dimsx)
+        assert arrayx.name == arrayx.__hint__ == "List[List[List[float]]]"
+
+    def test_name_override(self):
+        arrayx = ArrayX(fmt=single, name="array")
+        assert arrayx.__hint__ == "List[float]"
+        assert arrayx.name == "array"
