@@ -749,7 +749,9 @@ class ForTolerantEnum(BitFields, nbytes=1):
     """Sample BitFields subclass with enumeration field."""
 
     f1: int = bitfield(lsb=0, size=2)
-    f2: int = bitfield(lsb=2, size=4, typ=EnumX("myenum", MyEnum, strict=False))
+    f2: int = bitfield(
+        lsb=2, size=4, typ=EnumX(name="myenum", enum=MyEnum, strict=False)
+    )
     f3: int = bitfield(lsb=6, size=2)
 
 
