@@ -14,7 +14,7 @@ class TestGreedy(Case):
     """Test greedy."""
 
     data = CaseData(
-        fmt=BytesX("greedy_bytes"),
+        fmt=BytesX(name="greedy_bytes"),
         bindata=bytes(range(20)),
         nbytes=None,
         values=(bytes(range(20)),),
@@ -39,7 +39,7 @@ class TestFixedSize(Case):
     """Test fixed size."""
 
     data = CaseData(
-        fmt=BytesX("fixed", nbytes=20),
+        fmt=BytesX(name="fixed", nbytes=20),
         bindata=bytes(range(20)),
         nbytes=20,
         values=(bytes(range(20)),),
@@ -83,7 +83,7 @@ class TestFixedSize(Case):
 
         InsufficientMemoryError occurred during unpack operation:
 
-        1 too few bytes to unpack 'fixed' (20 needed, only 19 available)
+        1 too few bytes to unpack fixed, 20 needed, only 19 available
         """
         ),
     )
@@ -94,7 +94,7 @@ class TestPadded(Case):
     """Test fixed size with pad."""
 
     data = CaseData(
-        fmt=BytesX("padded", nbytes=20, pad=b"\x99"),
+        fmt=BytesX(name="padded", nbytes=20, pad=b"\x99"),
         bindata=bytes(range(15)) + b"\x99" * 5,
         nbytes=20,
         values=(bytes(range(15)),),
@@ -135,7 +135,7 @@ class TestNoBytes(Case):
     """Test value of length 0."""
 
     data = CaseData(
-        fmt=BytesX("greedy"),
+        fmt=BytesX(name="greedy"),
         bindata=b"",
         nbytes=None,
         values=(b"",),
