@@ -14,7 +14,7 @@ from plum.utilities import pack
 from sample_enum import Register
 
 
-register16 = EnumX("register16", Register, nbytes=2, byteorder="big", signed=False)
+register16 = EnumX(Register, nbytes=2, byteorder="big", signed=False, name="register16")
 
 
 class TestPack:
