@@ -6,14 +6,31 @@
 from plum.none import NoneX
 
 
+class TestDefault:
+
+    nonex = NoneX()
+
+    def test_hint(self):
+        assert self.nonex.__hint__ == "None"
+
+    def test_name(self):
+        assert self.nonex.name == "None"
+
+    def test_nbytes(self):
+        assert self.nonex.nbytes == 0
+
+
 class TestPositional:
 
     """Test explicitly defined with positional argument."""
 
-    nonex = NoneX("nonex")
+    nonex = NoneX("name")
+
+    def test_hint(self):
+        assert self.nonex.__hint__ == "None"
 
     def test_name(self):
-        assert self.nonex.name == "nonex"
+        assert self.nonex.name == "name"
 
     def test_nbytes(self):
         assert self.nonex.nbytes == 0
@@ -23,4 +40,4 @@ class TestKeyword(TestPositional):
 
     """Test explicitly defined with keyword argument."""
 
-    nonex = NoneX(name="nonex")
+    nonex = NoneX(name="name")
