@@ -39,34 +39,34 @@ class Test(Case):
         ),
         dump=Baseline(
             """
-            +--------+--------+-------+----------+----------+
-            | Offset | Access | Value | Bytes    | Format   |
-            +--------+--------+-------+----------+----------+
-            |        |        |       |          | MyStruct |
-            | 0      |        | 128   | 80       |          |
-            |        | m1     | 2     |          | Bits     |
-            |  [7]   |   b1   | True  | 1....... | bool     |
-            |  [6]   |   b2   | False | .0...... | bool     |
-            |  [0:6] | m2     | 0     | ..000000 | int      |
-            | 1      | m3     | 255   | ff       | uint8    |
-            +--------+--------+-------+----------+----------+
+            +--------+--------+-------+----------+----------------------+
+            | Offset | Access | Value | Bytes    | Format               |
+            +--------+--------+-------+----------+----------------------+
+            |        |        |       |          | MyStruct (Structure) |
+            | 0      |        | 128   | 80       |                      |
+            |        | m1     | 2     |          | Bits (BitFields)     |
+            |  [7]   |   b1   | True  | 1....... | bool                 |
+            |  [6]   |   b2   | False | .0...... | bool                 |
+            |  [0:6] | m2     | 0     | ..000000 | int                  |
+            | 1      | m3     | 255   | ff       | uint8                |
+            +--------+--------+-------+----------+----------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+--------+----------------+----------+----------+
-            | Offset | Access | Value          | Bytes    | Format   |
-            +--------+--------+----------------+----------+----------+
-            |        |        |                |          | MyStruct |
-            | 0      |        | 128            | 80       |          |
-            |        | m1     | 2              |          | Bits     |
-            |  [7]   |   b1   | True           | 1....... | bool     |
-            |  [6]   |   b2   | False          | .0...... | bool     |
-            |  [0:6] | m2     | 0              | ..000000 | int      |
-            | 1      | m3     | 255            | ff       | uint8    |
-            +--------+--------+----------------+----------+----------+
-            | 2      |        | <excess bytes> | 99       |          |
-            +--------+--------+----------------+----------+----------+
+            +--------+--------+----------------+----------+----------------------+
+            | Offset | Access | Value          | Bytes    | Format               |
+            +--------+--------+----------------+----------+----------------------+
+            |        |        |                |          | MyStruct (Structure) |
+            | 0      |        | 128            | 80       |                      |
+            |        | m1     | 2              |          | Bits (BitFields)     |
+            |  [7]   |   b1   | True           | 1....... | bool                 |
+            |  [6]   |   b2   | False          | .0...... | bool                 |
+            |  [0:6] | m2     | 0              | ..000000 | int                  |
+            | 1      | m3     | 255            | ff       | uint8                |
+            +--------+--------+----------------+----------+----------------------+
+            | 2      |        | <excess bytes> | 99       |                      |
+            +--------+--------+----------------+----------+----------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -75,21 +75,21 @@ class Test(Case):
         ),
         shortage=Baseline(
             """
-            +--------+--------+----------------------+----------+----------+
-            | Offset | Access | Value                | Bytes    | Format   |
-            +--------+--------+----------------------+----------+----------+
-            |        |        |                      |          | MyStruct |
-            | 0      |        | 128                  | 80       |          |
-            |        | m1     | 2                    |          | Bits     |
-            |  [7]   |   b1   | True                 | 1....... | bool     |
-            |  [6]   |   b2   | False                | .0...... | bool     |
-            |  [0:6] | m2     | 0                    | ..000000 | int      |
-            |        | m3     | <insufficient bytes> |          | uint8    |
-            +--------+--------+----------------------+----------+----------+
+            +--------+--------+----------------------+----------+----------------------+
+            | Offset | Access | Value                | Bytes    | Format               |
+            +--------+--------+----------------------+----------+----------------------+
+            |        |        |                      |          | MyStruct (Structure) |
+            | 0      |        | 128                  | 80       |                      |
+            |        | m1     | 2                    |          | Bits (BitFields)     |
+            |  [7]   |   b1   | True                 | 1....... | bool                 |
+            |  [6]   |   b2   | False                | .0...... | bool                 |
+            |  [0:6] | m2     | 0                    | ..000000 | int                  |
+            |        | m3     | <insufficient bytes> |          | uint8                |
+            +--------+--------+----------------------+----------+----------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
