@@ -40,32 +40,32 @@ class TestFirst(Case):
         ),
         dump=Baseline(
             """
-            +---------+--------+---------+-------------------+----------+
-            | Offset  | Access | Value   | Bytes             | Format   |
-            +---------+--------+---------+-------------------+----------+
-            |         |        |         |                   | MyStruct |
-            | 0       |        | 801     | 21 03             |          |
-            |  [0:4]  | m1     | Pet.DOG | ........ ....0001 | Pet      |
-            |  [4:8]  | m2     | 2       | ........ 0010.... | int      |
-            |  [8:16] | m3     | 3       | 00000011 ........ | int      |
-            | 2       | m4     | 4       | 04                | uint8    |
-            +---------+--------+---------+-------------------+----------+
+            +---------+--------+---------+-------------------+----------------------+
+            | Offset  | Access | Value   | Bytes             | Format               |
+            +---------+--------+---------+-------------------+----------------------+
+            |         |        |         |                   | MyStruct (Structure) |
+            | 0       |        | 801     | 21 03             |                      |
+            |  [0:4]  | m1     | Pet.DOG | ........ ....0001 | Pet                  |
+            |  [4:8]  | m2     | 2       | ........ 0010.... | int                  |
+            |  [8:16] | m3     | 3       | 00000011 ........ | int                  |
+            | 2       | m4     | 4       | 04                | uint8                |
+            +---------+--------+---------+-------------------+----------------------+
             """
         ),
         excess=Baseline(
             """
-            +---------+--------+----------------+-------------------+----------+
-            | Offset  | Access | Value          | Bytes             | Format   |
-            +---------+--------+----------------+-------------------+----------+
-            |         |        |                |                   | MyStruct |
-            | 0       |        | 801            | 21 03             |          |
-            |  [0:4]  | m1     | Pet.DOG        | ........ ....0001 | Pet      |
-            |  [4:8]  | m2     | 2              | ........ 0010.... | int      |
-            |  [8:16] | m3     | 3              | 00000011 ........ | int      |
-            | 2       | m4     | 4              | 04                | uint8    |
-            +---------+--------+----------------+-------------------+----------+
-            | 3       |        | <excess bytes> | 99                |          |
-            +---------+--------+----------------+-------------------+----------+
+            +---------+--------+----------------+-------------------+----------------------+
+            | Offset  | Access | Value          | Bytes             | Format               |
+            +---------+--------+----------------+-------------------+----------------------+
+            |         |        |                |                   | MyStruct (Structure) |
+            | 0       |        | 801            | 21 03             |                      |
+            |  [0:4]  | m1     | Pet.DOG        | ........ ....0001 | Pet                  |
+            |  [4:8]  | m2     | 2              | ........ 0010.... | int                  |
+            |  [8:16] | m3     | 3              | 00000011 ........ | int                  |
+            | 2       | m4     | 4              | 04                | uint8                |
+            +---------+--------+----------------+-------------------+----------------------+
+            | 3       |        | <excess bytes> | 99                |                      |
+            +---------+--------+----------------+-------------------+----------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -74,20 +74,20 @@ class TestFirst(Case):
         ),
         shortage=Baseline(
             """
-            +---------+--------+----------------------+-------------------+----------+
-            | Offset  | Access | Value                | Bytes             | Format   |
-            +---------+--------+----------------------+-------------------+----------+
-            |         |        |                      |                   | MyStruct |
-            | 0       |        | 801                  | 21 03             |          |
-            |  [0:4]  | m1     | Pet.DOG              | ........ ....0001 | Pet      |
-            |  [4:8]  | m2     | 2                    | ........ 0010.... | int      |
-            |  [8:16] | m3     | 3                    | 00000011 ........ | int      |
-            |         | m4     | <insufficient bytes> |                   | uint8    |
-            +---------+--------+----------------------+-------------------+----------+
+            +---------+--------+----------------------+-------------------+----------------------+
+            | Offset  | Access | Value                | Bytes             | Format               |
+            +---------+--------+----------------------+-------------------+----------------------+
+            |         |        |                      |                   | MyStruct (Structure) |
+            | 0       |        | 801                  | 21 03             |                      |
+            |  [0:4]  | m1     | Pet.DOG              | ........ ....0001 | Pet                  |
+            |  [4:8]  | m2     | 2                    | ........ 0010.... | int                  |
+            |  [8:16] | m3     | 3                    | 00000011 ........ | int                  |
+            |         | m4     | <insufficient bytes> |                   | uint8                |
+            +---------+--------+----------------------+-------------------+----------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -255,32 +255,32 @@ class TestLast(Case):
         values=(MyStruct(m0=0, m1=1, m2=2, m3=3), [0, 1, 2, 3], (0, 1, 2, 3)),
         dump=Baseline(
             """
-            +---------+--------+-------+-------------------+----------+
-            | Offset  | Access | Value | Bytes             | Format   |
-            +---------+--------+-------+-------------------+----------+
-            |         |        |       |                   | MyStruct |
-            | 0       | m0     | 0     | 00                | uint8    |
-            | 1       |        | 801   | 21 03             |          |
-            |  [0:4]  | m1     | 1     | ........ ....0001 | int      |
-            |  [4:8]  | m2     | 2     | ........ 0010.... | int      |
-            |  [8:16] | m3     | 3     | 00000011 ........ | int      |
-            +---------+--------+-------+-------------------+----------+
+            +---------+--------+-------+-------------------+----------------------+
+            | Offset  | Access | Value | Bytes             | Format               |
+            +---------+--------+-------+-------------------+----------------------+
+            |         |        |       |                   | MyStruct (Structure) |
+            | 0       | m0     | 0     | 00                | uint8                |
+            | 1       |        | 801   | 21 03             |                      |
+            |  [0:4]  | m1     | 1     | ........ ....0001 | int                  |
+            |  [4:8]  | m2     | 2     | ........ 0010.... | int                  |
+            |  [8:16] | m3     | 3     | 00000011 ........ | int                  |
+            +---------+--------+-------+-------------------+----------------------+
             """
         ),
         excess=Baseline(
             """
-            +---------+--------+----------------+-------------------+----------+
-            | Offset  | Access | Value          | Bytes             | Format   |
-            +---------+--------+----------------+-------------------+----------+
-            |         |        |                |                   | MyStruct |
-            | 0       | m0     | 0              | 00                | uint8    |
-            | 1       |        | 801            | 21 03             |          |
-            |  [0:4]  | m1     | 1              | ........ ....0001 | int      |
-            |  [4:8]  | m2     | 2              | ........ 0010.... | int      |
-            |  [8:16] | m3     | 3              | 00000011 ........ | int      |
-            +---------+--------+----------------+-------------------+----------+
-            | 3       |        | <excess bytes> | 99                |          |
-            +---------+--------+----------------+-------------------+----------+
+            +---------+--------+----------------+-------------------+----------------------+
+            | Offset  | Access | Value          | Bytes             | Format               |
+            +---------+--------+----------------+-------------------+----------------------+
+            |         |        |                |                   | MyStruct (Structure) |
+            | 0       | m0     | 0              | 00                | uint8                |
+            | 1       |        | 801            | 21 03             |                      |
+            |  [0:4]  | m1     | 1              | ........ ....0001 | int                  |
+            |  [4:8]  | m2     | 2              | ........ 0010.... | int                  |
+            |  [8:16] | m3     | 3              | 00000011 ........ | int                  |
+            +---------+--------+----------------+-------------------+----------------------+
+            | 3       |        | <excess bytes> | 99                |                      |
+            +---------+--------+----------------+-------------------+----------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -289,17 +289,17 @@ class TestLast(Case):
         ),
         shortage=Baseline(
             """
-            +--------+--------+----------------------+-------+----------+
-            | Offset | Access | Value                | Bytes | Format   |
-            +--------+--------+----------------------+-------+----------+
-            |        |        |                      |       | MyStruct |
-            | 0      | m0     | 0                    | 00    | uint8    |
-            | 1      |        | <insufficient bytes> | 21    |          |
-            +--------+--------+----------------------+-------+----------+
+            +--------+--------+----------------------+-------+----------------------+
+            | Offset | Access | Value                | Bytes | Format               |
+            +--------+--------+----------------------+-------+----------------------+
+            |        |        |                      |       | MyStruct (Structure) |
+            | 0      | m0     | 0                    | 00    | uint8                |
+            | 1      |        | <insufficient bytes> | 21    |                      |
+            +--------+--------+----------------------+-------+----------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack (2 needed, only 1 available)
+            1 too few bytes to unpack, 2 needed, only 1 available
             """
         ),
         implementation=Baseline(
@@ -480,44 +480,44 @@ class TestMultiple(Case):
         ),
         dump=Baseline(
             """
-            +---------+--------+-------+-------------------+----------+
-            | Offset  | Access | Value | Bytes             | Format   |
-            +---------+--------+-------+-------------------+----------+
-            |         |        |       |                   | MyStruct |
-            | 0       |        | 16    | 10 00             |          |
-            |  [0:4]  | m0     | 0     | ........ ....0000 | int      |
-            |  [4:12] | m1     | 1     | ....0000 0001.... | int      |
-            | 2       | m2     | 2     | 02                | uint8    |
-            | 3       |        | 67    | 43                |          |
-            |  [0:4]  | m3     | 3     | ....0011          | int      |
-            |  [4:8]  | m4     | 4     | 0100....          | int      |
-            | 4       | m5     | 5     | 05                | uint8    |
-            | 5       |        | 118   | 76 00             |          |
-            |  [0:4]  | m6     | 6     | ........ ....0110 | int      |
-            |  [4:12] | m7     | 7     | ....0000 0111.... | int      |
-            +---------+--------+-------+-------------------+----------+
+            +---------+--------+-------+-------------------+----------------------+
+            | Offset  | Access | Value | Bytes             | Format               |
+            +---------+--------+-------+-------------------+----------------------+
+            |         |        |       |                   | MyStruct (Structure) |
+            | 0       |        | 16    | 10 00             |                      |
+            |  [0:4]  | m0     | 0     | ........ ....0000 | int                  |
+            |  [4:12] | m1     | 1     | ....0000 0001.... | int                  |
+            | 2       | m2     | 2     | 02                | uint8                |
+            | 3       |        | 67    | 43                |                      |
+            |  [0:4]  | m3     | 3     | ....0011          | int                  |
+            |  [4:8]  | m4     | 4     | 0100....          | int                  |
+            | 4       | m5     | 5     | 05                | uint8                |
+            | 5       |        | 118   | 76 00             |                      |
+            |  [0:4]  | m6     | 6     | ........ ....0110 | int                  |
+            |  [4:12] | m7     | 7     | ....0000 0111.... | int                  |
+            +---------+--------+-------+-------------------+----------------------+
             """
         ),
         excess=Baseline(
             """
-            +---------+--------+----------------+-------------------+----------+
-            | Offset  | Access | Value          | Bytes             | Format   |
-            +---------+--------+----------------+-------------------+----------+
-            |         |        |                |                   | MyStruct |
-            | 0       |        | 16             | 10 00             |          |
-            |  [0:4]  | m0     | 0              | ........ ....0000 | int      |
-            |  [4:12] | m1     | 1              | ....0000 0001.... | int      |
-            | 2       | m2     | 2              | 02                | uint8    |
-            | 3       |        | 67             | 43                |          |
-            |  [0:4]  | m3     | 3              | ....0011          | int      |
-            |  [4:8]  | m4     | 4              | 0100....          | int      |
-            | 4       | m5     | 5              | 05                | uint8    |
-            | 5       |        | 118            | 76 00             |          |
-            |  [0:4]  | m6     | 6              | ........ ....0110 | int      |
-            |  [4:12] | m7     | 7              | ....0000 0111.... | int      |
-            +---------+--------+----------------+-------------------+----------+
-            | 7       |        | <excess bytes> | 99                |          |
-            +---------+--------+----------------+-------------------+----------+
+            +---------+--------+----------------+-------------------+----------------------+
+            | Offset  | Access | Value          | Bytes             | Format               |
+            +---------+--------+----------------+-------------------+----------------------+
+            |         |        |                |                   | MyStruct (Structure) |
+            | 0       |        | 16             | 10 00             |                      |
+            |  [0:4]  | m0     | 0              | ........ ....0000 | int                  |
+            |  [4:12] | m1     | 1              | ....0000 0001.... | int                  |
+            | 2       | m2     | 2              | 02                | uint8                |
+            | 3       |        | 67             | 43                |                      |
+            |  [0:4]  | m3     | 3              | ....0011          | int                  |
+            |  [4:8]  | m4     | 4              | 0100....          | int                  |
+            | 4       | m5     | 5              | 05                | uint8                |
+            | 5       |        | 118            | 76 00             |                      |
+            |  [0:4]  | m6     | 6              | ........ ....0110 | int                  |
+            |  [4:12] | m7     | 7              | ....0000 0111.... | int                  |
+            +---------+--------+----------------+-------------------+----------------------+
+            | 7       |        | <excess bytes> | 99                |                      |
+            +---------+--------+----------------+-------------------+----------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -526,24 +526,24 @@ class TestMultiple(Case):
         ),
         shortage=Baseline(
             """
-            +---------+--------+----------------------+-------------------+----------+
-            | Offset  | Access | Value                | Bytes             | Format   |
-            +---------+--------+----------------------+-------------------+----------+
-            |         |        |                      |                   | MyStruct |
-            | 0       |        | 16                   | 10 00             |          |
-            |  [0:4]  | m0     | 0                    | ........ ....0000 | int      |
-            |  [4:12] | m1     | 1                    | ....0000 0001.... | int      |
-            | 2       | m2     | 2                    | 02                | uint8    |
-            | 3       |        | 67                   | 43                |          |
-            |  [0:4]  | m3     | 3                    | ....0011          | int      |
-            |  [4:8]  | m4     | 4                    | 0100....          | int      |
-            | 4       | m5     | 5                    | 05                | uint8    |
-            | 5       |        | <insufficient bytes> | 76                |          |
-            +---------+--------+----------------------+-------------------+----------+
+            +---------+--------+----------------------+-------------------+----------------------+
+            | Offset  | Access | Value                | Bytes             | Format               |
+            +---------+--------+----------------------+-------------------+----------------------+
+            |         |        |                      |                   | MyStruct (Structure) |
+            | 0       |        | 16                   | 10 00             |                      |
+            |  [0:4]  | m0     | 0                    | ........ ....0000 | int                  |
+            |  [4:12] | m1     | 1                    | ....0000 0001.... | int                  |
+            | 2       | m2     | 2                    | 02                | uint8                |
+            | 3       |        | 67                   | 43                |                      |
+            |  [0:4]  | m3     | 3                    | ....0011          | int                  |
+            |  [4:8]  | m4     | 4                    | 0100....          | int                  |
+            | 4       | m5     | 5                    | 05                | uint8                |
+            | 5       |        | <insufficient bytes> | 76                |                      |
+            +---------+--------+----------------------+-------------------+----------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack (2 needed, only 1 available)
+            1 too few bytes to unpack, 2 needed, only 1 available
             """
         ),
         implementation=Baseline(
@@ -831,34 +831,34 @@ class TestArtificialSplit(Case):
         values=(MyStruct(m1=1, m2=2, m3=3, m4=4), [1, 2, 3, 4], (1, 2, 3, 4)),
         dump=Baseline(
             """
-            +--------+--------+-------+-------------------+----------+
-            | Offset | Access | Value | Bytes             | Format   |
-            +--------+--------+-------+-------------------+----------+
-            |        |        |       |                   | MyStruct |
-            | 0      |        | 33    | 21                |          |
-            |  [0:4] | m1     | 1     | ....0001          | int      |
-            |  [4:6] | m2     | 2     | ..10....          | int      |
-            | 1      |        | 67    | 43 00             |          |
-            |  [0:4] | m3     | 3     | ........ ....0011 | int      |
-            |  [4:8] | m4     | 4     | ........ 0100.... | int      |
-            +--------+--------+-------+-------------------+----------+
+            +--------+--------+-------+-------------------+----------------------+
+            | Offset | Access | Value | Bytes             | Format               |
+            +--------+--------+-------+-------------------+----------------------+
+            |        |        |       |                   | MyStruct (Structure) |
+            | 0      |        | 33    | 21                |                      |
+            |  [0:4] | m1     | 1     | ....0001          | int                  |
+            |  [4:6] | m2     | 2     | ..10....          | int                  |
+            | 1      |        | 67    | 43 00             |                      |
+            |  [0:4] | m3     | 3     | ........ ....0011 | int                  |
+            |  [4:8] | m4     | 4     | ........ 0100.... | int                  |
+            +--------+--------+-------+-------------------+----------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+--------+----------------+-------------------+----------+
-            | Offset | Access | Value          | Bytes             | Format   |
-            +--------+--------+----------------+-------------------+----------+
-            |        |        |                |                   | MyStruct |
-            | 0      |        | 33             | 21                |          |
-            |  [0:4] | m1     | 1              | ....0001          | int      |
-            |  [4:6] | m2     | 2              | ..10....          | int      |
-            | 1      |        | 67             | 43 00             |          |
-            |  [0:4] | m3     | 3              | ........ ....0011 | int      |
-            |  [4:8] | m4     | 4              | ........ 0100.... | int      |
-            +--------+--------+----------------+-------------------+----------+
-            | 3      |        | <excess bytes> | 99                |          |
-            +--------+--------+----------------+-------------------+----------+
+            +--------+--------+----------------+-------------------+----------------------+
+            | Offset | Access | Value          | Bytes             | Format               |
+            +--------+--------+----------------+-------------------+----------------------+
+            |        |        |                |                   | MyStruct (Structure) |
+            | 0      |        | 33             | 21                |                      |
+            |  [0:4] | m1     | 1              | ....0001          | int                  |
+            |  [4:6] | m2     | 2              | ..10....          | int                  |
+            | 1      |        | 67             | 43 00             |                      |
+            |  [0:4] | m3     | 3              | ........ ....0011 | int                  |
+            |  [4:8] | m4     | 4              | ........ 0100.... | int                  |
+            +--------+--------+----------------+-------------------+----------------------+
+            | 3      |        | <excess bytes> | 99                |                      |
+            +--------+--------+----------------+-------------------+----------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -867,19 +867,19 @@ class TestArtificialSplit(Case):
         ),
         shortage=Baseline(
             """
-            +--------+--------+----------------------+----------+----------+
-            | Offset | Access | Value                | Bytes    | Format   |
-            +--------+--------+----------------------+----------+----------+
-            |        |        |                      |          | MyStruct |
-            | 0      |        | 33                   | 21       |          |
-            |  [0:4] | m1     | 1                    | ....0001 | int      |
-            |  [4:6] | m2     | 2                    | ..10.... | int      |
-            | 1      |        | <insufficient bytes> | 43       |          |
-            +--------+--------+----------------------+----------+----------+
+            +--------+--------+----------------------+----------+----------------------+
+            | Offset | Access | Value                | Bytes    | Format               |
+            +--------+--------+----------------------+----------+----------------------+
+            |        |        |                      |          | MyStruct (Structure) |
+            | 0      |        | 33                   | 21       |                      |
+            |  [0:4] | m1     | 1                    | ....0001 | int                  |
+            |  [4:6] | m2     | 2                    | ..10.... | int                  |
+            | 1      |        | <insufficient bytes> | 43       |                      |
+            +--------+--------+----------------------+----------+----------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack (2 needed, only 1 available)
+            1 too few bytes to unpack, 2 needed, only 1 available
             """
         ),
         implementation=Baseline(
