@@ -33,26 +33,26 @@ class TestMethod(Case):
         ),
         dump=Baseline(
             """
-            +--------+--------+-------+-------+--------+
-            | Offset | Access | Value | Bytes | Format |
-            +--------+--------+-------+-------+--------+
-            |        |        |       |       | Struct |
-            | 0      | prev   | 0     | 00    | uint8  |
-            | 1      | data   | 16    | 10    | uint8  |
-            +--------+--------+-------+-------+--------+
+            +--------+--------+-------+-------+--------------------+
+            | Offset | Access | Value | Bytes | Format             |
+            +--------+--------+-------+-------+--------------------+
+            |        |        |       |       | Struct (Structure) |
+            | 0      | prev   | 0     | 00    | uint8              |
+            | 1      | data   | 16    | 10    | uint8              |
+            +--------+--------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+--------+----------------+-------+--------+
-            | Offset | Access | Value          | Bytes | Format |
-            +--------+--------+----------------+-------+--------+
-            |        |        |                |       | Struct |
-            | 0      | prev   | 0              | 00    | uint8  |
-            | 1      | data   | 16             | 10    | uint8  |
-            +--------+--------+----------------+-------+--------+
-            | 2      |        | <excess bytes> | 99    |        |
-            +--------+--------+----------------+-------+--------+
+            +--------+--------+----------------+-------+--------------------+
+            | Offset | Access | Value          | Bytes | Format             |
+            +--------+--------+----------------+-------+--------------------+
+            |        |        |                |       | Struct (Structure) |
+            | 0      | prev   | 0              | 00    | uint8              |
+            | 1      | data   | 16             | 10    | uint8              |
+            +--------+--------+----------------+-------+--------------------+
+            | 2      |        | <excess bytes> | 99    |                    |
+            +--------+--------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -61,17 +61,17 @@ class TestMethod(Case):
         ),
         shortage=Baseline(
             """
-            +--------+--------+----------------------+-------+--------+
-            | Offset | Access | Value                | Bytes | Format |
-            +--------+--------+----------------------+-------+--------+
-            |        |        |                      |       | Struct |
-            | 0      | prev   | 0                    | 00    | uint8  |
-            |        | data   | <insufficient bytes> |       | uint8  |
-            +--------+--------+----------------------+-------+--------+
+            +--------+--------+----------------------+-------+--------------------+
+            | Offset | Access | Value                | Bytes | Format             |
+            +--------+--------+----------------------+-------+--------------------+
+            |        |        |                      |       | Struct (Structure) |
+            | 0      | prev   | 0                    | 00    | uint8              |
+            |        | data   | <insufficient bytes> |       | uint8              |
+            +--------+--------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -182,26 +182,26 @@ class TestProperty(Case):
         ),
         dump=Baseline(
             """
-            +--------+--------+-------+-------+--------+
-            | Offset | Access | Value | Bytes | Format |
-            +--------+--------+-------+-------+--------+
-            |        |        |       |       | Struct |
-            | 0      | prev   | 0     | 00    | uint8  |
-            | 1      | data   | 16    | 10    | uint8  |
-            +--------+--------+-------+-------+--------+
+            +--------+--------+-------+-------+--------------------+
+            | Offset | Access | Value | Bytes | Format             |
+            +--------+--------+-------+-------+--------------------+
+            |        |        |       |       | Struct (Structure) |
+            | 0      | prev   | 0     | 00    | uint8              |
+            | 1      | data   | 16    | 10    | uint8              |
+            +--------+--------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+--------+----------------+-------+--------+
-            | Offset | Access | Value          | Bytes | Format |
-            +--------+--------+----------------+-------+--------+
-            |        |        |                |       | Struct |
-            | 0      | prev   | 0              | 00    | uint8  |
-            | 1      | data   | 16             | 10    | uint8  |
-            +--------+--------+----------------+-------+--------+
-            | 2      |        | <excess bytes> | 99    |        |
-            +--------+--------+----------------+-------+--------+
+            +--------+--------+----------------+-------+--------------------+
+            | Offset | Access | Value          | Bytes | Format             |
+            +--------+--------+----------------+-------+--------------------+
+            |        |        |                |       | Struct (Structure) |
+            | 0      | prev   | 0              | 00    | uint8              |
+            | 1      | data   | 16             | 10    | uint8              |
+            +--------+--------+----------------+-------+--------------------+
+            | 2      |        | <excess bytes> | 99    |                    |
+            +--------+--------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -210,17 +210,17 @@ class TestProperty(Case):
         ),
         shortage=Baseline(
             """
-            +--------+--------+----------------------+-------+--------+
-            | Offset | Access | Value                | Bytes | Format |
-            +--------+--------+----------------------+-------+--------+
-            |        |        |                      |       | Struct |
-            | 0      | prev   | 0                    | 00    | uint8  |
-            |        | data   | <insufficient bytes> |       | uint8  |
-            +--------+--------+----------------------+-------+--------+
+            +--------+--------+----------------------+-------+--------------------+
+            | Offset | Access | Value                | Bytes | Format             |
+            +--------+--------+----------------------+-------+--------------------+
+            |        |        |                      |       | Struct (Structure) |
+            | 0      | prev   | 0                    | 00    | uint8              |
+            |        | data   | <insufficient bytes> |       | uint8              |
+            +--------+--------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
