@@ -18,7 +18,7 @@ from plum.str import StrX
 from plum.structure import Structure, member, sized_member
 from plum.utilities import unpack
 
-ascii_greedy = StrX("ascii", encoding="ascii")
+ascii_greedy = StrX(name="ascii", encoding="ascii")
 
 
 class Simple(Structure):
@@ -30,7 +30,7 @@ class Simple(Structure):
     bookend: int = member(fmt=uint8)
 
 
-sizedstrarray = ArrayX("sizedstrarray", fmt=Simple)
+sizedstrarray = ArrayX(name="sizedstrarray", fmt=Simple)
 
 
 class TestSimple(Case):
@@ -45,30 +45,30 @@ class TestSimple(Case):
         ),
         dump=Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Simple |
-            |  0     | size     | 12             | 0c                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | Offset | Access   | Value          | Bytes                               | Format             |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            |        |          |                |                                     | Simple (Structure) |
+            |  0     | size     | 12             | 0c                                  | uint8              |
+            |        | string   |                |                                     | ascii              |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+            | 13     | bookend  | 153            | 99                                  | uint8              |
+            +--------+----------+----------------+-------------------------------------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Simple |
-            |  0     | size     | 12             | 0c                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
-            | 14     |          | <excess bytes> | 99                                  |        |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | Offset | Access   | Value          | Bytes                               | Format             |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            |        |          |                |                                     | Simple (Structure) |
+            |  0     | size     | 12             | 0c                                  | uint8              |
+            |        | string   |                |                                     | ascii              |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+            | 13     | bookend  | 153            | 99                                  | uint8              |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | 14     |          | <excess bytes> | 99                                  |                    |
+            +--------+----------+----------------+-------------------------------------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -77,19 +77,19 @@ class TestSimple(Case):
         ),
         shortage=Baseline(
             """
-        +--------+----------+----------------------+-------------------------------------+--------+
-        | Offset | Access   | Value                | Bytes                               | Format |
-        +--------+----------+----------------------+-------------------------------------+--------+
-        |        |          |                      |                                     | Simple |
-        |  0     | size     | 12                   | 0c                                  | uint8  |
-        |        | string   |                      |                                     | ascii  |
-        |  1     |   [0:12] | 'Hello World!'       | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-        |        | bookend  | <insufficient bytes> |                                     | uint8  |
-        +--------+----------+----------------------+-------------------------------------+--------+
+        +--------+----------+----------------------+-------------------------------------+--------------------+
+        | Offset | Access   | Value                | Bytes                               | Format             |
+        +--------+----------+----------------------+-------------------------------------+--------------------+
+        |        |          |                      |                                     | Simple (Structure) |
+        |  0     | size     | 12                   | 0c                                  | uint8              |
+        |        | string   |                      |                                     | ascii              |
+        |  1     |   [0:12] | 'Hello World!'       | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+        |        | bookend  | <insufficient bytes> |                                     | uint8              |
+        +--------+----------+----------------------+-------------------------------------+--------------------+
 
         InsufficientMemoryError occurred during unpack operation:
 
-        1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+        1 too few bytes to unpack uint8, 1 needed, only 0 available
         """
         ),
         implementation=Baseline(
@@ -251,15 +251,15 @@ class TestSimple(Case):
         """Test explicit size value used instead of computed size."""
         expected_dump = Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Simple |
-            |  0     | size     | 32             | 20                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | Offset | Access   | Value          | Bytes                               | Format             |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            |        |          |                |                                     | Simple (Structure) |
+            |  0     | size     | 32             | 20                                  | uint8              |
+            |        | string   |                |                                     | ascii              |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+            | 13     | bookend  | 153            | 99                                  | uint8              |
+            +--------+----------+----------------+-------------------------------------+--------------------+
             """
         )
 
@@ -320,16 +320,16 @@ class TestMetaException:
 
         expected = Baseline(
             """
-            +--------+--------+----------------+-------------------------------------------------+-------------+
-            | Offset | Access | Value          | Bytes                                           | Format      |
-            +--------+--------+----------------+-------------------------------------------------+-------------+
-            |        |        |                |                                                 | ExcessBytes |
-            |  0     | size   | 32             | 20                                              | uint8       |
-            |  1     | fixed  | 0              | 00                                              | uint8       |
-            +--------+--------+----------------+-------------------------------------------------+-------------+
-            |  2     |        | <excess bytes> | 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 |             |
-            | 18     |        |                | 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00    |             |
-            +--------+--------+----------------+-------------------------------------------------+-------------+
+            +--------+--------+----------------+-------------------------------------------------+-------------------------+
+            | Offset | Access | Value          | Bytes                                           | Format                  |
+            +--------+--------+----------------+-------------------------------------------------+-------------------------+
+            |        |        |                |                                                 | ExcessBytes (Structure) |
+            |  0     | size   | 32             | 20                                              | uint8                   |
+            |  1     | fixed  | 0              | 00                                              | uint8                   |
+            +--------+--------+----------------+-------------------------------------------------+-------------------------+
+            |  2     |        | <excess bytes> | 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 |                         |
+            | 18     |        |                | 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00    |                         |
+            +--------+--------+----------------+-------------------------------------------------+-------------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -378,30 +378,30 @@ class TestRatio(Case):
         ),
         dump=Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Ratio  |
-            |  0     | size     | 6              | 06                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            | Offset | Access   | Value          | Bytes                               | Format            |
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            |        |          |                |                                     | Ratio (Structure) |
+            |  0     | size     | 6              | 06                                  | uint8             |
+            |        | string   |                |                                     | ascii             |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                   |
+            | 13     | bookend  | 153            | 99                                  | uint8             |
+            +--------+----------+----------------+-------------------------------------+-------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Ratio  |
-            |  0     | size     | 6              | 06                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
-            | 14     |          | <excess bytes> | 99                                  |        |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            | Offset | Access   | Value          | Bytes                               | Format            |
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            |        |          |                |                                     | Ratio (Structure) |
+            |  0     | size     | 6              | 06                                  | uint8             |
+            |        | string   |                |                                     | ascii             |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                   |
+            | 13     | bookend  | 153            | 99                                  | uint8             |
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            | 14     |          | <excess bytes> | 99                                  |                   |
+            +--------+----------+----------------+-------------------------------------+-------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -410,19 +410,19 @@ class TestRatio(Case):
         ),
         shortage=Baseline(
             """
-        +--------+----------+----------------------+-------------------------------------+--------+
-        | Offset | Access   | Value                | Bytes                               | Format |
-        +--------+----------+----------------------+-------------------------------------+--------+
-        |        |          |                      |                                     | Ratio  |
-        |  0     | size     | 6                    | 06                                  | uint8  |
-        |        | string   |                      |                                     | ascii  |
-        |  1     |   [0:12] | 'Hello World!'       | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-        |        | bookend  | <insufficient bytes> |                                     | uint8  |
-        +--------+----------+----------------------+-------------------------------------+--------+
+        +--------+----------+----------------------+-------------------------------------+-------------------+
+        | Offset | Access   | Value                | Bytes                               | Format            |
+        +--------+----------+----------------------+-------------------------------------+-------------------+
+        |        |          |                      |                                     | Ratio (Structure) |
+        |  0     | size     | 6                    | 06                                  | uint8             |
+        |        | string   |                      |                                     | ascii             |
+        |  1     |   [0:12] | 'Hello World!'       | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                   |
+        |        | bookend  | <insufficient bytes> |                                     | uint8             |
+        +--------+----------+----------------------+-------------------------------------+-------------------+
 
         InsufficientMemoryError occurred during unpack operation:
 
-        1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+        1 too few bytes to unpack uint8, 1 needed, only 0 available
         """
         ),
         implementation=Baseline(
@@ -587,15 +587,15 @@ class TestRatio(Case):
 
         expected_dump = Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Ratio  |
-            |  0     | size     | 32             | 20                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            | Offset | Access   | Value          | Bytes                               | Format            |
+            +--------+----------+----------------+-------------------------------------+-------------------+
+            |        |          |                |                                     | Ratio (Structure) |
+            |  0     | size     | 32             | 20                                  | uint8             |
+            |        | string   |                |                                     | ascii             |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                   |
+            | 13     | bookend  | 153            | 99                                  | uint8             |
+            +--------+----------+----------------+-------------------------------------+-------------------+
             """
         )
         buffer, dump = Ratio(
@@ -615,23 +615,23 @@ class Nested(Structure):
 
 NESTED_DUMP = Baseline(
     """
-    +--------+--------------+----------------+-------------------------------------+---------------+
-    | Offset | Access       | Value          | Bytes                               | Format        |
-    +--------+--------------+----------------+-------------------------------------+---------------+
-    |        |              |                |                                     | Nested        |
-    |  0     | size         | 25             | 19                                  | uint8         |
-    |        | array        |                |                                     | sizedstrarray |
-    |        |   [0]        |                |                                     | Simple        |
-    |  1     |     size     | 12             | 0c                                  | uint8         |
-    |        |     string   |                |                                     | ascii         |
-    |  2     |       [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |               |
-    | 14     |     bookend  | 153            | 99                                  | uint8         |
-    |        |   [1]        |                |                                     | Simple        |
-    | 15     |     size     | 9              | 09                                  | uint8         |
-    |        |     string   |                |                                     | ascii         |
-    | 16     |       [0:9]  | 'Good Bye!'    | 47 6f 6f 64 20 42 79 65 21          |               |
-    | 25     |     bookend  | 153            | 99                                  | uint8         |
-    +--------+--------------+----------------+-------------------------------------+---------------+
+    +--------+--------------+----------------+-------------------------------------+--------------------+
+    | Offset | Access       | Value          | Bytes                               | Format             |
+    +--------+--------------+----------------+-------------------------------------+--------------------+
+    |        |              |                |                                     | Nested (Structure) |
+    |  0     | size         | 25             | 19                                  | uint8              |
+    |        | array        |                |                                     | sizedstrarray      |
+    |        |   [0]        |                |                                     | Simple (Structure) |
+    |  1     |     size     | 12             | 0c                                  | uint8              |
+    |        |     string   |                |                                     | ascii              |
+    |  2     |       [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+    | 14     |     bookend  | 153            | 99                                  | uint8              |
+    |        |   [1]        |                |                                     | Simple (Structure) |
+    | 15     |     size     | 9              | 09                                  | uint8              |
+    |        |     string   |                |                                     | ascii              |
+    | 16     |       [0:9]  | 'Good Bye!'    | 47 6f 6f 64 20 42 79 65 21          |                    |
+    | 25     |     bookend  | 153            | 99                                  | uint8              |
+    +--------+--------------+----------------+-------------------------------------+--------------------+
     """
 )
 
@@ -659,23 +659,23 @@ class TestNested:
         """Test explicit size value used instead of computed size."""
         expected_dump = Baseline(
             """
-            +--------+--------------+----------------+-------------------------------------+---------------+
-            | Offset | Access       | Value          | Bytes                               | Format        |
-            +--------+--------------+----------------+-------------------------------------+---------------+
-            |        |              |                |                                     | Nested        |
-            |  0     | size         | 32             | 20                                  | uint8         |
-            |        | array        |                |                                     | sizedstrarray |
-            |        |   [0]        |                |                                     | Simple        |
-            |  1     |     size     | 12             | 0c                                  | uint8         |
-            |        |     string   |                |                                     | ascii         |
-            |  2     |       [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |               |
-            | 14     |     bookend  | 153            | 99                                  | uint8         |
-            |        |   [1]        |                |                                     | Simple        |
-            | 15     |     size     | 9              | 09                                  | uint8         |
-            |        |     string   |                |                                     | ascii         |
-            | 16     |       [0:9]  | 'Good Bye!'    | 47 6f 6f 64 20 42 79 65 21          |               |
-            | 25     |     bookend  | 153            | 99                                  | uint8         |
-            +--------+--------------+----------------+-------------------------------------+---------------+
+            +--------+--------------+----------------+-------------------------------------+--------------------+
+            | Offset | Access       | Value          | Bytes                               | Format             |
+            +--------+--------------+----------------+-------------------------------------+--------------------+
+            |        |              |                |                                     | Nested (Structure) |
+            |  0     | size         | 32             | 20                                  | uint8              |
+            |        | array        |                |                                     | sizedstrarray      |
+            |        |   [0]        |                |                                     | Simple (Structure) |
+            |  1     |     size     | 12             | 0c                                  | uint8              |
+            |        |     string   |                |                                     | ascii              |
+            |  2     |       [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+            | 14     |     bookend  | 153            | 99                                  | uint8              |
+            |        |   [1]        |                |                                     | Simple (Structure) |
+            | 15     |     size     | 9              | 09                                  | uint8              |
+            |        |     string   |                |                                     | ascii              |
+            | 16     |       [0:9]  | 'Good Bye!'    | 47 6f 6f 64 20 42 79 65 21          |                    |
+            | 25     |     bookend  | 153            | 99                                  | uint8              |
+            +--------+--------------+----------------+-------------------------------------+--------------------+
             """
         )
 
@@ -694,20 +694,20 @@ class TestNested:
 
         expected = Baseline(
             """
-            +--------+------------+----------------------+----------------+---------------+
-            | Offset | Access     | Value                | Bytes          | Format        |
-            +--------+------------+----------------------+----------------+---------------+
-            |        |            |                      |                | Nested        |
-            | 0      | size       | 6                    | 06             | uint8         |
-            |        | array      |                      |                | sizedstrarray |
-            |        |   [0]      |                      |                | Simple        |
-            | 1      |     size   | 12                   | 0c             | uint8         |
-            | 2      |     string | <insufficient bytes> | 48 65 6c 6c 6f | ascii         |
-            +--------+------------+----------------------+----------------+---------------+
+            +--------+------------+----------------------+----------------+--------------------+
+            | Offset | Access     | Value                | Bytes          | Format             |
+            +--------+------------+----------------------+----------------+--------------------+
+            |        |            |                      |                | Nested (Structure) |
+            | 0      | size       | 6                    | 06             | uint8              |
+            |        | array      |                      |                | sizedstrarray      |
+            |        |   [0]      |                      |                | Simple (Structure) |
+            | 1      |     size   | 12                   | 0c             | uint8              |
+            | 2      |     string | <insufficient bytes> | 48 65 6c 6c 6f | ascii              |
+            +--------+------------+----------------------+----------------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            7 too few bytes to unpack 'ascii' (12 needed, only 5 available)
+            7 too few bytes to unpack ascii, 12 needed, only 5 available
             """
         )
 
@@ -730,19 +730,19 @@ class TestNested:
 
         expected = Baseline(
             """
-            +--------+----------+----------------------+----------------+-----------+
-            | Offset | Access   | Value                | Bytes          | Format    |
-            +--------+----------+----------------------+----------------+-----------+
-            |        |          |                      |                | NestedStr |
-            | 0      | size     | 6                    | 06             | uint8     |
-            |        | simple   |                      |                | Simple    |
-            | 1      |   size   | 12                   | 0c             | uint8     |
-            | 2      |   string | <insufficient bytes> | 48 65 6c 6c 6f | ascii     |
-            +--------+----------+----------------------+----------------+-----------+
+            +--------+----------+----------------------+----------------+-----------------------+
+            | Offset | Access   | Value                | Bytes          | Format                |
+            +--------+----------+----------------------+----------------+-----------------------+
+            |        |          |                      |                | NestedStr (Structure) |
+            | 0      | size     | 6                    | 06             | uint8                 |
+            |        | simple   |                      |                | Simple (Structure)    |
+            | 1      |   size   | 12                   | 0c             | uint8                 |
+            | 2      |   string | <insufficient bytes> | 48 65 6c 6c 6f | ascii                 |
+            +--------+----------+----------------------+----------------+-----------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            7 too few bytes to unpack 'ascii' (12 needed, only 5 available)
+            7 too few bytes to unpack ascii, 12 needed, only 5 available
             """
         )
 
@@ -765,30 +765,30 @@ class TestNoCompute(Case):
         values=(Struct(size=12, string="Hello World!", bookend=0x99),),
         dump=Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Struct |
-            |  0     | size     | 12             | 0c                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | Offset | Access   | Value          | Bytes                               | Format             |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            |        |          |                |                                     | Struct (Structure) |
+            |  0     | size     | 12             | 0c                                  | uint8              |
+            |        | string   |                |                                     | ascii              |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+            | 13     | bookend  | 153            | 99                                  | uint8              |
+            +--------+----------+----------------+-------------------------------------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------------------------------------+--------+
-            | Offset | Access   | Value          | Bytes                               | Format |
-            +--------+----------+----------------+-------------------------------------+--------+
-            |        |          |                |                                     | Struct |
-            |  0     | size     | 12             | 0c                                  | uint8  |
-            |        | string   |                |                                     | ascii  |
-            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-            | 13     | bookend  | 153            | 99                                  | uint8  |
-            +--------+----------+----------------+-------------------------------------+--------+
-            | 14     |          | <excess bytes> | 99                                  |        |
-            +--------+----------+----------------+-------------------------------------+--------+
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | Offset | Access   | Value          | Bytes                               | Format             |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            |        |          |                |                                     | Struct (Structure) |
+            |  0     | size     | 12             | 0c                                  | uint8              |
+            |        | string   |                |                                     | ascii              |
+            |  1     |   [0:12] | 'Hello World!' | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+            | 13     | bookend  | 153            | 99                                  | uint8              |
+            +--------+----------+----------------+-------------------------------------+--------------------+
+            | 14     |          | <excess bytes> | 99                                  |                    |
+            +--------+----------+----------------+-------------------------------------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -797,19 +797,19 @@ class TestNoCompute(Case):
         ),
         shortage=Baseline(
             """
-        +--------+----------+----------------------+-------------------------------------+--------+
-        | Offset | Access   | Value                | Bytes                               | Format |
-        +--------+----------+----------------------+-------------------------------------+--------+
-        |        |          |                      |                                     | Struct |
-        |  0     | size     | 12                   | 0c                                  | uint8  |
-        |        | string   |                      |                                     | ascii  |
-        |  1     |   [0:12] | 'Hello World!'       | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |        |
-        |        | bookend  | <insufficient bytes> |                                     | uint8  |
-        +--------+----------+----------------------+-------------------------------------+--------+
+        +--------+----------+----------------------+-------------------------------------+--------------------+
+        | Offset | Access   | Value                | Bytes                               | Format             |
+        +--------+----------+----------------------+-------------------------------------+--------------------+
+        |        |          |                      |                                     | Struct (Structure) |
+        |  0     | size     | 12                   | 0c                                  | uint8              |
+        |        | string   |                      |                                     | ascii              |
+        |  1     |   [0:12] | 'Hello World!'       | 48 65 6c 6c 6f 20 57 6f 72 6c 64 21 |                    |
+        |        | bookend  | <insufficient bytes> |                                     | uint8              |
+        +--------+----------+----------------------+-------------------------------------+--------------------+
 
         InsufficientMemoryError occurred during unpack operation:
 
-        1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+        1 too few bytes to unpack uint8, 1 needed, only 0 available
         """
         ),
         implementation=Baseline(
